cutByTable.
The default return will find dividing points at three
quantiles: c(0.25, 0.50, 0.75) If n=4, the dividing
points will be c(0.20, 0.40, 0.60, 0.80) If n=5, c(0.0,
0.25, 0.50, 0.75, 1.0) Larger n that are odd will include
0.5 and evenly spaced points out to proportions 0 and
1.0. Larger n that is even will return evenly spaced
points calculated by R's pretty function.cutByQuantile(x, n = 3)