Use can supply either a single value (the common
correlation among all variables), a column of the lower
triangular values for a correlation matrix, or a
candidate matrix. The function will check X and do the
right thing. If X is a matrix, check that it is a valid
correlation matrix. If its a single value, use that to
fill up a matrix. If itis a vector, try to use it as a
vech to fill the lower triangle..
Usage
lazyCor(X, d)
Arguments
X
Required. May be one value, a vech, or a matrix
d
Optional. The number of rows in the correlation
matrix to be created. lazyCor will deduce the desired
size from X if possible. If X is a single value, d is a
required argument.