kurtosis(x, na.rm = TRUE, excess = TRUE, unbiased = TRUE)Many researchers use the term kurtosis to refer to "excess kurtosis" and this function follows suit by returning excess kurtosis. The user may avoid this by setting excess = FALSE, in which case kurtosis is returned.
If na.rm = FALSE and there are missing values, the mean and variance are undefined and this function returns NA.
The kurtosis may be calculated with the small-sample
bias-corrected estimate of the variance. Set unbiased = FALSE if
this is not desired. It appears somewhat controversial whether
this is necessary, hence the argument unbiased. According to the
US NIST,
where var(x) is calculated with the denominator N, rather than N-1.
A distribution is said to be leptokurtotic if it is tightly bunched in the center (spiked) and there are long, narrow tails representing extreme values that might occur.